==> alluxio-shaded-client-2.5.0-sources.jar: alluxio/grpc/SaslAuthenticationServiceGrpc.java <==
package alluxio.grpc;

import static alluxio.shaded.client.io.grpc.MethodDescriptor.generateFullMethodName;
import static alluxio.shaded.client.io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static alluxio.shaded.client.io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static alluxio.shaded.client.io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static alluxio.shaded.client.io.grpc.stub.ClientCalls.asyncUnaryCall;
import static alluxio.shaded.client.io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static alluxio.shaded.client.io.grpc.stub.ClientCalls.blockingUnaryCall;
import static alluxio.shaded.client.io.grpc.stub.ClientCalls.futureUnaryCall;
import static alluxio.shaded.client.io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static alluxio.shaded.client.io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static alluxio.shaded.client.io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static alluxio.shaded.client.io.grpc.stub.ServerCalls.asyncUnaryCall;
import static alluxio.shaded.client.io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static alluxio.shaded.client.io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@alluxio.shaded.client.javax.annotation.Generated(
    value = "by gRPC proto alluxio.shaded.client.com.iler (version 1.28.1)",
    alluxio.shaded.client.com.ents = "Source: grpc/sasl_server.proto")
public final class SaslAuthenticationServiceGrpc {

  private SaslAuthenticationServiceGrpc() {}

  public static final String SERVICE_NAME = "alluxio.grpc.sasl.SaslAuthenticationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile alluxio.shaded.client.io.grpc.MethodDescriptor<alluxio.grpc.SaslMessage,
      alluxio.grpc.SaslMessage> getAuthenticateMethod;

  @alluxio.shaded.client.io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "authenticate",
      requestType = alluxio.grpc.SaslMessage.class,
      responseType = alluxio.grpc.SaslMessage.class,
      methodType = alluxio.shaded.client.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static alluxio.shaded.client.io.grpc.MethodDescriptor<alluxio.grpc.SaslMessage,
      alluxio.grpc.SaslMessage> getAuthenticateMethod() {
    alluxio.shaded.client.io.grpc.MethodDescriptor<alluxio.grpc.SaslMessage, alluxio.grpc.SaslMessage> getAuthenticateMethod;
    if ((getAuthenticateMethod = SaslAuthenticationServiceGrpc.getAuthenticateMethod) == null) {
      synchronized (SaslAuthenticationServiceGrpc.class) {
        if ((getAuthenticateMethod = SaslAuthenticationServiceGrpc.getAuthenticateMethod) == null) {
          SaslAuthenticationServiceGrpc.getAuthenticateMethod = getAuthenticateMethod =
              alluxio.shaded.client.io.grpc.MethodDescriptor.<alluxio.grpc.SaslMessage, alluxio.grpc.SaslMessage>newBuilder()
              .setType(alluxio.shaded.client.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "authenticate"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(alluxio.shaded.client.io.grpc.protobuf.ProtoUtils.marshaller(
                  alluxio.grpc.SaslMessage.getDefaultInstance()))
              .setResponseMarshaller(alluxio.shaded.client.io.grpc.protobuf.ProtoUtils.marshaller(
                  alluxio.grpc.SaslMessage.getDefaultInstance()))
              .setSchemaDescriptor(new SaslAuthenticationServiceMethodDescriptorSupplier("authenticate"))
              .build();
        }
      }
    }
    return getAuthenticateMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static SaslAuthenticationServiceStub newStub(alluxio.shaded.client.io.grpc.Channel channel) {
    alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceStub> factory =
      new alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceStub>() {
        @java.lang.Override
        public SaslAuthenticationServiceStub newStub(alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
          return new SaslAuthenticationServiceStub(channel, callOptions);
        }
      };
    return SaslAuthenticationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static SaslAuthenticationServiceBlockingStub newBlockingStub(
      alluxio.shaded.client.io.grpc.Channel channel) {
    alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceBlockingStub> factory =
      new alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceBlockingStub>() {
        @java.lang.Override
        public SaslAuthenticationServiceBlockingStub newStub(alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
          return new SaslAuthenticationServiceBlockingStub(channel, callOptions);
        }
      };
    return SaslAuthenticationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static SaslAuthenticationServiceFutureStub newFutureStub(
      alluxio.shaded.client.io.grpc.Channel channel) {
    alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceFutureStub> factory =
      new alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceFutureStub>() {
        @java.lang.Override
        public SaslAuthenticationServiceFutureStub newStub(alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
          return new SaslAuthenticationServiceFutureStub(channel, callOptions);
        }
      };
    return SaslAuthenticationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class SaslAuthenticationServiceImplBase implements alluxio.shaded.client.io.grpc.BindableService {

    /**
     * <pre>
     **
     * Used to drive Sasl negotiation with clients.
     * </pre>
     */
    public alluxio.shaded.client.io.grpc.stub.StreamObserver<alluxio.grpc.SaslMessage> authenticate(
        alluxio.shaded.client.io.grpc.stub.StreamObserver<alluxio.grpc.SaslMessage> responseObserver) {
      return asyncUnimplementedStreamingCall(getAuthenticateMethod(), responseObserver);
    }

    @java.lang.Override public final alluxio.shaded.client.io.grpc.ServerServiceDefinition bindService() {
      return alluxio.shaded.client.io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getAuthenticateMethod(),
            asyncBidiStreamingCall(
              new MethodHandlers<
                alluxio.grpc.SaslMessage,
                alluxio.grpc.SaslMessage>(
                  this, METHODID_AUTHENTICATE)))
          .build();
    }
  }

  /**
   */
  public static final class SaslAuthenticationServiceStub extends alluxio.shaded.client.io.grpc.stub.AbstractAsyncStub<SaslAuthenticationServiceStub> {
    private SaslAuthenticationServiceStub(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected SaslAuthenticationServiceStub build(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      return new SaslAuthenticationServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     **
     * Used to drive Sasl negotiation with clients.
     * </pre>
     */
    public alluxio.shaded.client.io.grpc.stub.StreamObserver<alluxio.grpc.SaslMessage> authenticate(
        alluxio.shaded.client.io.grpc.stub.StreamObserver<alluxio.grpc.SaslMessage> responseObserver) {
      return asyncBidiStreamingCall(
          getChannel().newCall(getAuthenticateMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   */
  public static final class SaslAuthenticationServiceBlockingStub extends alluxio.shaded.client.io.grpc.stub.AbstractBlockingStub<SaslAuthenticationServiceBlockingStub> {
    private SaslAuthenticationServiceBlockingStub(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected SaslAuthenticationServiceBlockingStub build(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      return new SaslAuthenticationServiceBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class SaslAuthenticationServiceFutureStub extends alluxio.shaded.client.io.grpc.stub.AbstractFutureStub<SaslAuthenticationServiceFutureStub> {
    private SaslAuthenticationServiceFutureStub(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected SaslAuthenticationServiceFutureStub build(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      return new SaslAuthenticationServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_AUTHENTICATE = 0;

  private static final class MethodHandlers<Req, Resp> implements
      alluxio.shaded.client.io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      alluxio.shaded.client.io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      alluxio.shaded.client.io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      alluxio.shaded.client.io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final SaslAuthenticationServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(SaslAuthenticationServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, alluxio.shaded.client.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public alluxio.shaded.client.io.grpc.stub.StreamObserver<Req> invoke(
        alluxio.shaded.client.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_AUTHENTICATE:
          return (alluxio.shaded.client.io.grpc.stub.StreamObserver<Req>) serviceImpl.authenticate(
              (alluxio.shaded.client.io.grpc.stub.StreamObserver<alluxio.grpc.SaslMessage>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class SaslAuthenticationServiceBaseDescriptorSupplier
      implements alluxio.shaded.client.io.grpc.protobuf.ProtoFileDescriptorSupplier, alluxio.shaded.client.io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    SaslAuthenticationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public alluxio.shaded.client.com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return alluxio.grpc.AuthenticationServerProto.getDescriptor();
    }

    @java.lang.Override
    public alluxio.shaded.client.com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("SaslAuthenticationService");
    }
  }

  private static final class SaslAuthenticationServiceFileDescriptorSupplier
      extends SaslAuthenticationServiceBaseDescriptorSupplier {
    SaslAuthenticationServiceFileDescriptorSupplier() {}
  }

  private static final class SaslAuthenticationServiceMethodDescriptorSupplier
      extends SaslAuthenticationServiceBaseDescriptorSupplier
      implements alluxio.shaded.client.io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    SaslAuthenticationServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public alluxio.shaded.client.com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile alluxio.shaded.client.io.grpc.ServiceDescriptor serviceDescriptor;

  public static alluxio.shaded.client.io.grpc.ServiceDescriptor getServiceDescriptor() {
    alluxio.shaded.client.io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (SaslAuthenticationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = alluxio.shaded.client.io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new SaslAuthenticationServiceFileDescriptorSupplier())
              .addMethod(getAuthenticateMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> alluxio-shaded-client-2.8.0-1-sources.jar: alluxio/grpc/SaslAuthenticationServiceGrpc.java <==
package alluxio.grpc;

import static alluxio.shaded.client.io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@alluxio.shaded.client.javax.annotation.Generated(
    value = "by gRPC proto alluxio.shaded.client.com.iler (version 1.37.0)",
    alluxio.shaded.client.com.ents = "Source: grpc/sasl_server.proto")
public final class SaslAuthenticationServiceGrpc {

  private SaslAuthenticationServiceGrpc() {}

  public static final String SERVICE_NAME = "alluxio.grpc.sasl.SaslAuthenticationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile alluxio.shaded.client.io.grpc.MethodDescriptor<alluxio.grpc.SaslMessage,
      alluxio.grpc.SaslMessage> getAuthenticateMethod;

  @alluxio.shaded.client.io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "authenticate",
      requestType = alluxio.grpc.SaslMessage.class,
      responseType = alluxio.grpc.SaslMessage.class,
      methodType = alluxio.shaded.client.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static alluxio.shaded.client.io.grpc.MethodDescriptor<alluxio.grpc.SaslMessage,
      alluxio.grpc.SaslMessage> getAuthenticateMethod() {
    alluxio.shaded.client.io.grpc.MethodDescriptor<alluxio.grpc.SaslMessage, alluxio.grpc.SaslMessage> getAuthenticateMethod;
    if ((getAuthenticateMethod = SaslAuthenticationServiceGrpc.getAuthenticateMethod) == null) {
      synchronized (SaslAuthenticationServiceGrpc.class) {
        if ((getAuthenticateMethod = SaslAuthenticationServiceGrpc.getAuthenticateMethod) == null) {
          SaslAuthenticationServiceGrpc.getAuthenticateMethod = getAuthenticateMethod =
              alluxio.shaded.client.io.grpc.MethodDescriptor.<alluxio.grpc.SaslMessage, alluxio.grpc.SaslMessage>newBuilder()
              .setType(alluxio.shaded.client.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "authenticate"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(alluxio.shaded.client.io.grpc.protobuf.ProtoUtils.marshaller(
                  alluxio.grpc.SaslMessage.getDefaultInstance()))
              .setResponseMarshaller(alluxio.shaded.client.io.grpc.protobuf.ProtoUtils.marshaller(
                  alluxio.grpc.SaslMessage.getDefaultInstance()))
              .setSchemaDescriptor(new SaslAuthenticationServiceMethodDescriptorSupplier("authenticate"))
              .build();
        }
      }
    }
    return getAuthenticateMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static SaslAuthenticationServiceStub newStub(alluxio.shaded.client.io.grpc.Channel channel) {
    alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceStub> factory =
      new alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceStub>() {
        @java.lang.Override
        public SaslAuthenticationServiceStub newStub(alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
          return new SaslAuthenticationServiceStub(channel, callOptions);
        }
      };
    return SaslAuthenticationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static SaslAuthenticationServiceBlockingStub newBlockingStub(
      alluxio.shaded.client.io.grpc.Channel channel) {
    alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceBlockingStub> factory =
      new alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceBlockingStub>() {
        @java.lang.Override
        public SaslAuthenticationServiceBlockingStub newStub(alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
          return new SaslAuthenticationServiceBlockingStub(channel, callOptions);
        }
      };
    return SaslAuthenticationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static SaslAuthenticationServiceFutureStub newFutureStub(
      alluxio.shaded.client.io.grpc.Channel channel) {
    alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceFutureStub> factory =
      new alluxio.shaded.client.io.grpc.stub.AbstractStub.StubFactory<SaslAuthenticationServiceFutureStub>() {
        @java.lang.Override
        public SaslAuthenticationServiceFutureStub newStub(alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
          return new SaslAuthenticationServiceFutureStub(channel, callOptions);
        }
      };
    return SaslAuthenticationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class SaslAuthenticationServiceImplBase implements alluxio.shaded.client.io.grpc.BindableService {

    /**
     * <pre>
     **
     * Used to drive Sasl negotiation with clients.
     * </pre>
     */
    public alluxio.shaded.client.io.grpc.stub.StreamObserver<alluxio.grpc.SaslMessage> authenticate(
        alluxio.shaded.client.io.grpc.stub.StreamObserver<alluxio.grpc.SaslMessage> responseObserver) {
      return alluxio.shaded.client.io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall(getAuthenticateMethod(), responseObserver);
    }

    @java.lang.Override public final alluxio.shaded.client.io.grpc.ServerServiceDefinition bindService() {
      return alluxio.shaded.client.io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getAuthenticateMethod(),
            alluxio.shaded.client.io.grpc.stub.ServerCalls.asyncBidiStreamingCall(
              new MethodHandlers<
                alluxio.grpc.SaslMessage,
                alluxio.grpc.SaslMessage>(
                  this, METHODID_AUTHENTICATE)))
          .build();
    }
  }

  /**
   */
  public static final class SaslAuthenticationServiceStub extends alluxio.shaded.client.io.grpc.stub.AbstractAsyncStub<SaslAuthenticationServiceStub> {
    private SaslAuthenticationServiceStub(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected SaslAuthenticationServiceStub build(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      return new SaslAuthenticationServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     **
     * Used to drive Sasl negotiation with clients.
     * </pre>
     */
    public alluxio.shaded.client.io.grpc.stub.StreamObserver<alluxio.grpc.SaslMessage> authenticate(
        alluxio.shaded.client.io.grpc.stub.StreamObserver<alluxio.grpc.SaslMessage> responseObserver) {
      return alluxio.shaded.client.io.grpc.stub.ClientCalls.asyncBidiStreamingCall(
          getChannel().newCall(getAuthenticateMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   */
  public static final class SaslAuthenticationServiceBlockingStub extends alluxio.shaded.client.io.grpc.stub.AbstractBlockingStub<SaslAuthenticationServiceBlockingStub> {
    private SaslAuthenticationServiceBlockingStub(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected SaslAuthenticationServiceBlockingStub build(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      return new SaslAuthenticationServiceBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class SaslAuthenticationServiceFutureStub extends alluxio.shaded.client.io.grpc.stub.AbstractFutureStub<SaslAuthenticationServiceFutureStub> {
    private SaslAuthenticationServiceFutureStub(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected SaslAuthenticationServiceFutureStub build(
        alluxio.shaded.client.io.grpc.Channel channel, alluxio.shaded.client.io.grpc.CallOptions callOptions) {
      return new SaslAuthenticationServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_AUTHENTICATE = 0;

  private static final class MethodHandlers<Req, Resp> implements
      alluxio.shaded.client.io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      alluxio.shaded.client.io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      alluxio.shaded.client.io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      alluxio.shaded.client.io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final SaslAuthenticationServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(SaslAuthenticationServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, alluxio.shaded.client.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public alluxio.shaded.client.io.grpc.stub.StreamObserver<Req> invoke(
        alluxio.shaded.client.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_AUTHENTICATE:
          return (alluxio.shaded.client.io.grpc.stub.StreamObserver<Req>) serviceImpl.authenticate(
              (alluxio.shaded.client.io.grpc.stub.StreamObserver<alluxio.grpc.SaslMessage>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class SaslAuthenticationServiceBaseDescriptorSupplier
      implements alluxio.shaded.client.io.grpc.protobuf.ProtoFileDescriptorSupplier, alluxio.shaded.client.io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    SaslAuthenticationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public alluxio.shaded.client.com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return alluxio.grpc.AuthenticationServerProto.getDescriptor();
    }

    @java.lang.Override
    public alluxio.shaded.client.com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("SaslAuthenticationService");
    }
  }

  private static final class SaslAuthenticationServiceFileDescriptorSupplier
      extends SaslAuthenticationServiceBaseDescriptorSupplier {
    SaslAuthenticationServiceFileDescriptorSupplier() {}
  }

  private static final class SaslAuthenticationServiceMethodDescriptorSupplier
      extends SaslAuthenticationServiceBaseDescriptorSupplier
      implements alluxio.shaded.client.io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    SaslAuthenticationServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public alluxio.shaded.client.com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile alluxio.shaded.client.io.grpc.ServiceDescriptor serviceDescriptor;

  public static alluxio.shaded.client.io.grpc.ServiceDescriptor getServiceDescriptor() {
    alluxio.shaded.client.io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (SaslAuthenticationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = alluxio.shaded.client.io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new SaslAuthenticationServiceFileDescriptorSupplier())
              .addMethod(getAuthenticateMethod())
              .build();
        }
      }
    }
    return result;
  }
}
